#!/usr/bin/env python3

import sys
import numpy as np
from matplotlib import pyplot
from matplotlib import colors
import matplotlib.animation as animation
from numpy.core.numeric import Inf

size = 16
STATES = {"ON", "OFF"}

def generateGrid(size):
    return np.random.choice(list(STATES), size*size, p=[0.3, 0.7]).reshape(size, size)

def update(frameNum, img, grid, N):
    nextMoment = grid.copy()

    empty = True
    for i in range(N):
        for j in range(N):
            if grid[i, j] != 0:
                empty = False
                break

    if empty:
        sys.exit()

    for i in range(N):
        for j in range(N):
            total = int((grid[i, (j-1)%N] + grid[i, (j+1)%N] +
                         grid[(i-1)%N, j] + grid[(i+1)%N, j] +
                         grid[(i-1)%N, (j-1)%N] + grid[(i-1)%N, (j+1)%N] +
                         grid[(i+1)%N, (j-1)%N] + grid[(i+1)%N, (j+1)%N]))
            
            # Apply the rules
            if grid[i, j] == 1:
                if (total < 2) or (total > 3):
                    nextMoment[i, j] = 0
            else:
                if total == 3:
                    nextMoment[i, j] = 1

    img.set_data(nextMoment)
    grid[:] = nextMoment[:]
    return img

def main():
    global size
    if len(sys.argv) == 2:
        size = int(sys.argv[1])

    grid = generateGrid(size)
    oneZero = np.where(grid == "ON", 1, 0)

    # set up animation
    updateInterval = 3000
    fig, ax = pyplot.subplots(figsize=(8,8))
    ax.set_title("The Game of Life", size=28)
    ax.tick_params(left=False, bottom=False,
        labelleft=False, labelbottom=False)
    colormap = colors.ListedColormap(["white", "black"])
    img = ax.imshow(oneZero, cmap=colormap, interpolation='nearest')

    ani = animation.FuncAnimation(fig, update, 
                    fargs=(img, oneZero, size, ),
                    interval=updateInterval)
    pyplot.show()

if __name__ == '__main__':
	main()
