#!/usr/bin/env python3

import numpy as np
from matplotlib import pyplot
from matplotlib import colors
import matplotlib.animation as animation
from numpy.core.numeric import Inf

size = 16
STATES = {"ON", "OFF"}

def generateGrid(size):
    return np.random.choice(list(STATES), size*size, p=[0.3, 0.7]).reshape(size, size)

def update(frameNum, img, grid, N):
    newGrid = grid.copy()
    for i in range(N):
        for j in range(N):
            if grid[i, j]  == 1:
                newGrid[i, j] = 0
            else:
                newGrid[i, j] = 1

    img.set_data(newGrid)
    grid[:] = newGrid[:]
    return img

def main():
    grid = generateGrid(size)

    oneZero = np.where(grid == "ON", 1, 0)
    print(oneZero)

    # set up animation
    updateInterval = 2000
    fig, ax = pyplot.subplots(figsize=(8,8))
    ax.set_title("The Game of Life", size=28)
    ax.tick_params(left=False, bottom=False,
        labelleft=False, labelbottom=False)
    colormap = colors.ListedColormap(["white", "black"])
    img = ax.imshow(oneZero, cmap=colormap, interpolation='nearest')

    ani = animation.FuncAnimation(fig, update, fargs=(img, oneZero, size, ),
                                  interval=updateInterval)
    pyplot.show()

if __name__ == '__main__':
	main()
